==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Block/ts/Block_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>Инструменты работы с блоками</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>Показать инструменты работы с блоками</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>Блок</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.js" line="+115"/>
        <source>Leading or trailing spaces.</source>
        <translation>Начальные или завершающие пробелы.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>Не указано наименование блока.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>Неверное наименование блока.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation>Блок &apos;%1&apos; уже существует&lt;br&gt;и будет перезаписан.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>Блок уже существует.</translation>
    </message>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>Данные блока</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>Наименование блока:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>блок 1</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Block/ts/Block_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>Block</name>
    <message>
        <location filename="../Block.js" line="+67"/>
        <source>Block Tools</source>
        <translation>Инструменты работы с блоками</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show block tools</source>
        <translation>Показать инструменты работы с блоками</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Block</source>
        <translation>Блок</translation>
    </message>
</context>
<context>
    <name>BlockDialog</name>
    <message>
        <location filename="../BlockDialog.js" line="+134"/>
        <source>Leading or trailing spaces.</source>
        <translation>Начальные или завершающие пробелы.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is empty.</source>
        <translation>Не указано наименование блока.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block name is invalid.</source>
        <translation>Неверное наименование блока.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Block &apos;%1&apos; already exists&lt;br&gt;and will be overwritten.</source>
        <translation>Блок &apos;%1&apos; уже существует&lt;br&gt;и будет перезаписан.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Block already exists.</source>
        <translation>Блок уже существует.</translation>
    </message>
    <message>
        <location filename="../BlockDialog.ui" line="+17"/>
        <source>Block Data</source>
        <translation>Данные блока</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Block name:</source>
        <translation>Наименование блока:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>block 1</source>
        <translation>блок 1</translation>
    </message>
</context>
<context>
    <name>LayoutDialog</name>
    <message>
        <source>Leading or trailing spaces.</source>
        <translation type="obsolete">Начальные или завершающие пробелы.</translation>
    </message>
</context>
</TS>
